#!/usr/bin/perl

use strict;
use warnings;

# check arguments and print usage
if (scalar(@ARGV) != 4) {
	print "Usage: perl blast_filter.pl <blast_file.txt> <min_identity> <max_evalue> <min_score>\n";
	exit;
}

# save arguments in variables
my ($blast_file,$ident_limit,$eval_lmit,$score_limit) = @ARGV;

# duplicate input name and transform it in the output name
my $output_name = $blast_file;
$output_name =~ s/\.txt$/_filtered.txt/;

# open file to write the output
open (my $out_fh, ">", $output_name);

# open input file and read it line by line
open (my $blast_fh, "<", $blast_file) || die ("\nERROR: the file ".$blast_file." could not be found\n");
while (my $line = <$blast_fh>) {
	chomp($line);
	
	# split lines by tabs getting each column value in a variable
	my ($query,$subject,$identity,$alignment_length,$mismatch,$gapopen,$qstart,$qend,$sstart,$send,$evalue,$bitscore) = split("\t",$line);
	
	# compare line values with limit values
	if (($identity >= $ident_limit) && ($bitscore >= $score_limit) && ($evalue <= $eval_lmit)) {
		# print "$line\n";
		$query =~ s/\.\d\.\d$//;
		print "$query\t$subject\t$identity\t$evalue\t$bitscore\n";
		print $out_fh "$line\n";
	}
}

